@@ -6,7 +6,7 @@ use Moo;
 use HTML::TableContent::Parser;
 use HTML::TableContent::Table;
 
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 
 has parser => (
     is      => 'rw',
@@ -255,11 +255,11 @@ __END__
 
 =head1 NAME
 
-HTML::TableContent - Extract content from HTML tables.
+HTML::TableContent - HTML tables.
 
 =head1 VERSION
 
-Version 0.11 
+Version 0.12 
 
 =cut
 
