@@ -3,15 +3,21 @@ package HTML::TableContent::Element;
 use Moo;
 use HTML::TableContent::Table;
 
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 
-my @ATTRIBUTE = qw/class id style colspan rowspan/;
+my @ATTRIBUTE = qw/class id style colspan rowspan template_attr/;
 
 around BUILDARGS => sub {
     my ( $orig, $class, $args ) = @_;
     
     my $build = ( );
 
+    if (my $links = delete $args->{links}) {
+        if ( ref $links eq 'ARRAY' ) {
+            $build->{links} = $links;
+        }
+    }
+
     $build->{attributes} = $args;
     $build->{attribute_list} = \@ATTRIBUTE;
 
@@ -20,7 +26,7 @@ around BUILDARGS => sub {
             $build->{$field} = $args->{$field};
         }
     }
-    
+
     return $class->$orig( $build );
 };
 
@@ -34,22 +40,27 @@ for my $field (@ATTRIBUTE) {
 }
 
 has attributes => (
-    is      => 'rw',
+    is => 'rw',
     default => sub { {} }
 );
 
 has attribute_list => (
-    is      => 'rw',
+    is => 'rw',
 );
 
 has data => (
-    is      => 'rw',
+    is => 'rw',
     clearer => 1,
     builder => 1,
 );
 
+has inner_html => (
+    is => 'rw',
+    lazy => 1,
+);
+
 has [qw/nested links/] => (
-    is      => 'rw',
+    is => 'rw',
     default => sub { [] },
 );
 
@@ -68,6 +79,16 @@ sub get_nested { return $_[0]->nested->[ $_[1] ]; }
 
 sub all_nested { return @{ $_[0]->nested }; }
 
+sub has_links { return scalar @{ $_[0]->links } ? 1 : 0; }
+
+sub count_links { return scalar @{ $_[0]->links }; }
+
+sub get_first_link { return $_[0]->links->[0]; }
+
+sub get_link { return $_[0]->links->[ $_[1] ]; }
+
+sub all_links { return @{ $_[0]->links }; }
+
 sub add_nested { 
     my $table = HTML::TableContent::Table->new($_[1]);
     push @{ $_[0]->nested }, $table;
@@ -82,6 +103,8 @@ sub text { return join q{ }, @{ $_[0]->data }; }
 
 sub add_text { return push @{ $_[0]->data }, $_[1]; }
 
+sub set_text { $_[0]->data([ $_[1] ]); }
+
 sub lc_text { return lc $_[0]->text; }
 
 sub add_class { my $class = $_[0]->class; return $_[0]->class(sprintf('%s %s', $class, $_[1])); }
@@ -111,13 +134,27 @@ sub render {
     
     my $attr = '';
     foreach my $attribute (@{ $_[0]->attribute_list }) {
+        next if $attribute eq 'template_attr';
         if (my $val = $args->{$attribute}) {
             $attr .= sprintf '%s="%s" ', $attribute, $val;
         }
     }
 
+    my $render = $_[0]->_render_element;
+
+    if ( my $inner_html = $_[0]->inner_html ) {
+       my $inner_count = scalar @{ $inner_html };
+       if ( $inner_count == 1 ) {
+            $render = sprintf($inner_html->[0], $render);
+       } else {
+           use Data::Dumper;
+           my @inner = @{ $inner_html };
+            $render = sprintf($inner_html->[0], map { $_[0]->$_ } @{ $inner_html }[1 .. $inner_count - 1] );
+       }
+    }
+
     my $tag = $_[0]->html_tag;
-    return $_[0]->tidy_html(sprintf("<%s %s>%s</%s>", $tag, $attr, $_[0]->_render_element, $tag));
+    return $_[0]->tidy_html(sprintf("<%s %s>%s</%s>", $tag, $attr, $render, $tag));
 }
 
 sub _render_element {
@@ -134,6 +171,8 @@ sub _trigger_colspan { return $_[0]->attributes->{colspan} = $_[1]; }
 
 sub _trigger_rowspan { return $_[0]->attributes->{rowspan} = $_[1]; }
 
+sub _trigger_template_attr { return $_[0]->attributes->{template_attr} = $_[1]; }
+
 sub _build_data {
     my $data = delete $_[0]->attributes->{data};
     my $text = delete $_[0]->attributes->{text};
@@ -163,7 +202,7 @@ HTML::TableContent::Element - attributes, text, data, class, id
 
 =head1 VERSION
 
-Version 0.11
+Version 0.12
 
 =cut
 
@@ -188,7 +227,7 @@ and L<HTML::TableContent::Table::Caption>
 
 =head2 attributes
 
-hash consisting of the html attributes belonding to the current element.
+hash consisting of the html attributes belonging to the current element.
 
     $element->attributes;
 
@@ -264,6 +303,42 @@ ArrayRef of href links.
 
     $element->links;
 
+=head2 all_links
+
+Array of links.
+
+    $element->links
+
+=head2 has_links
+
+Boolean check, returns true if the element has links.
+
+    $element->has_links
+
+=head2 count_links
+
+Count number of links.
+
+    $element->count_links
+
+=head2 get_first_link
+
+Get the first nested table.
+
+    $element->get_first_link
+
+=head2 get_last_link
+
+Get the first nested table.
+
+    $element->get_last_link
+
+=head2 get_link
+
+Get Nested table by index.
+
+    $element->get_link(1);
+
 =head1 AUTHOR
 
 LNATION, C<< <thisusedtobeanemail at gmail.com> >>
