@@ -2,7 +2,7 @@ package HTML::TableContent::Table::Row::Cell;
 
 use Moo;
 
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 
 extends 'HTML::TableContent::Element';
 
@@ -26,6 +26,14 @@ around _render_element => sub {
     return $text;
 };
 
+sub header_template_attr {
+    return $_[0]->header->template_attr;
+}
+
+sub header_text {
+    return $_[0]->header->text;
+}
+
 __PACKAGE__->meta->make_immutable;
 
 1;
@@ -38,7 +46,7 @@ HTML::TableContent::Table::Row::Cell - base class for table cells.
 
 =head1 VERSION
 
-Version 0.11
+Version 0.12
 
 =head1 SYNOPSIS
 
@@ -150,6 +158,48 @@ Add nested L<HTML::TableContent::Table> to the Cell.
 
     $cell->add_nested({ id => 'nested-table-id', class => 'nested-table-class' }); 
 
+=head2 links
+
+ArrayRef of href links.
+
+    $cell->links;
+
+=head2 all_links
+
+Array of links.
+
+    $cell->links
+
+=head2 has_links
+
+Boolean check, returns true if the element has links.
+
+    $cell->has_links
+
+=head2 count_links
+
+Count number of links.
+
+    $cell->count_links
+
+=head2 get_first_link
+
+Get the first nested table.
+
+    $cell->get_first_link
+
+=head2 get_last_link
+
+Get the first nested table.
+
+    $cell->get_last_link
+
+=head2 get_link
+
+Get Nested table by index.
+
+    $cell->get_link(1);
+
 =head1 AUTHOR
 
 LNATION, C<< <thisusedtobeanemail at gmail.com> >>
